from django.test import TestCase
from django.urls import reverse
from django.contrib.auth.models import Group
from guardian.shortcuts import assign_perm
from . import models

class WireguardTest(TestCase):
    """Check keys are listed"""

    def test_list_public(self):
        """Check that public keys are listed"""
        toykey = models.WireguardPublicKey.objects.create(
            interface="example.com",
            key="mykey",
        )
        any_user = Group.objects.get(name="any-user")
        assign_perm('view_wireguardpublickey', any_user, toykey)

        response = self.client.get(
            reverse('wireguard-list')
        )
        self.assertEqual(response.status_code, 200)
        self.assertContains(response, toykey.key)

    def test_list_private(self):
        """Check that private keys are not listed"""
        toykey = models.WireguardPublicKey.objects.create(
            interface="example.com",
            key="mykey",
        )

        response = self.client.get(
            reverse('wireguard-list')
        )
        self.assertEqual(response.status_code, 200)
        self.assertNotContains(response, toykey.key)
